0.1.9 (2013-03-04)
-------------------
- add an reshard example
- tidy the pipeline code
- add more shard methods

0.1.8 (2013-01-21)
-------------------
add `append` and `getrange` method, thks @simon-liu

0.1.7 (2012-11-19)
-------------------
use new redis url config instead of dict 

0.1.5 (2012-07-16)
-------------------
Add many new methods, support socket_timeout and password

0.1.4 (2011-07-20)
------------------
modify hash key algor,support suffix match,thks to dkong 
support more redis methods,include `keys`.

0.1.3 (2011-06-20)
------------------
support 2.4.X version of redis-py

0.1.2 (2011-06-01)
------------------
add MANIFEST.in file

0.1.1 (2011-05-29)
------------------
create hashring use server's name config.

0.1 (2011-05-28)
------------------
first version
